@@ -516,7 +516,8 @@ void ConstanteExtension::decoration(SVM_Valeur::Decorateur& decorateur)
 	SVM_String sv;
 	sv.string = s.c_str();
 	sv.size = s.size();
-	SVM_Interface::EnvironnementSP environnement = std::make_shared<SVM_Interface::Environnement>(t,decorateur._machine,decorateur._machine->_base->_gestionnaire_extensions->variables_extension(_type.nom_extension()));
+	auto cache_appellant = std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>();
+	SVM_Interface::EnvironnementSP environnement = std::make_shared<SVM_Interface::Environnement>(t,decorateur._machine,cache_appellant,decorateur._machine->_base->_gestionnaire_extensions->variables_extension(_type.nom_extension()));
 	try
 	{
 		void *v=t->_constante(&environnement,sv);
